package mastermind.client;

import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelListener;
import java.awt.event.MouseWheelEvent;
import javax.swing.*;

/**
 * Mastermind GUI Mous Listener
 */
/* -----------------------------------------------------------------------------
 * Version History:
 * 2012-05-11.v01   ReMa    init version
 * 2012-05-13.v01   ReMa    div Neuerungen (MouseListener, Results, etc.)
 * -----------------------------------------------------------------------------
 * @author Marco Reichmuth <marco.reichmuth@stud.hslu.ch>
 * @version 2012-05-13.v01
 */
public class ClientGUIMouseListener implements MouseListener, MouseWheelListener
{

    private ClientGUI gui;

    /**
     * Default Konstruktor
     * @param gui Mastermind GUI
     */
    public ClientGUIMouseListener(ClientGUI gui)
    {
        this.gui = gui;
    }

    /**
     * MouseClicked Event Handler
     * @param e Event
     */
    public void mouseClicked(MouseEvent e)
    {
        JLabel label = (JLabel) e.getSource();
        String str = label.getName();
        char ch = str.charAt(0);
        if (ch == 'h') {
            int PegID = str.charAt(1) - '0';
            gui.incHiddenValue(PegID);
            gui.validateNewHiddenGuess();
        } else {
            int temp = Integer.parseInt(str);
            int i = temp / 100;
            int j = temp % 100;

            gui.incValue(i, j);

        }
    }

    /**
     * mouseWheelMoved Event Handler
     * @param mwe Event
     */
    public void mouseWheelMoved(MouseWheelEvent mwe)
    {
        JLabel label = (JLabel) mwe.getSource();
        String str = label.getName();
        char ch = str.charAt(0);
        if (ch == 'h') {
            int PegID = str.charAt(1) - '0';
            if (mwe.getWheelRotation() < 0) {
                gui.decHiddenValue(PegID);
                gui.validateNewHiddenGuess();
            } else {
                gui.incHiddenValue(PegID);
                gui.validateNewHiddenGuess();
            }

        } else {
            int temp = Integer.parseInt(str);
            int i = temp / 100;
            int j = temp % 100;

            if (mwe.getWheelRotation() < 0) {
                gui.decValue(i, j);
            } else {
                gui.incValue(i, j);
            }
        }
    }

    /**
     * mouseEntered - not used
     * @param e Event
     */
    public void mouseEntered(MouseEvent e)
    {
        // empty
    }

    /**
     * mouseExited - not used
     * @param e Event
     */
    public void mouseExited(MouseEvent e)
    {
        // empty
    }

    /**
     * mousePressed - not used
     * @param e event
     */
    public void mousePressed(MouseEvent e)
    {
        // empty
    }

    /**
     * mouseReleased - not used
     * @param e event
     */
    public void mouseReleased(MouseEvent e)
    {
        // empty
    }
}
