package mastermind.client;

import javax.swing.JDialog;
import mastermind.logic.SettingsHandler;
import mastermind.model.Settings;

/**
 * Mastermind GUI Settings.
 */
/* -----------------------------------------------------------------------------
 * Version History:
 * 2012-05-20.v01   FeRo    init version
 * -----------------------------------------------------------------------------
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 * @version 2012-05-20.v01
 */
public class ClientGUISettings extends javax.swing.JPanel
{
    private String[] jCBColorList;
    private String[] jCBColorDoubleList;
    private String[] jCBPegList;
    private String[] jCBRowList;
    private String[] jCBDesignList;
    JDialog myDialog;

    /** Creates new form FeRoSett
     * @param myDialog Mastermind-Gui
     */
    public ClientGUISettings(JDialog myDialog)
    {
        this.myDialog = myDialog;

        Settings mySettings = SettingsHandler.getInstance().getSettings();

        // init Lists
        jCBColorList = new String[Settings.ANZ_COLOR_MAX - Settings.ANZ_COLOR_MIN + 1];
        for (int i = Settings.ANZ_COLOR_MIN; i <= Settings.ANZ_COLOR_MAX; i ++) {
            jCBColorList[i - Settings.ANZ_COLOR_MIN] = Integer.toString(i);
        }

        jCBColorDoubleList = new String[]{"Yes", "No"};

        jCBPegList = new String[Settings.ANZ_PEG_MAX - Settings.ANZ_PEG_MIN + 1];
        for (int i = Settings.ANZ_PEG_MIN; i <= Settings.ANZ_PEG_MAX; i ++) {
            jCBPegList[i - Settings.ANZ_PEG_MIN] = Integer.toString(i);
        }

        jCBRowList = new String[Settings.ANZ_GUESS_MAX - Settings.ANZ_GUESS_MIN + 1];
        for (int i = Settings.ANZ_GUESS_MIN; i <= Settings.ANZ_GUESS_MAX; i ++) {
            jCBRowList[i - Settings.ANZ_GUESS_MIN] = Integer.toString(i);
        }

        jCBDesignList = new String[]{"Color", "Smiley", "Cube", "Owl","Car","World","Tux"};

        initComponents();

        // set default
        jCBColor.setSelectedIndex((mySettings.getNumberOfColors() - Settings.ANZ_COLOR_MIN));
        if (mySettings.getAllowDuplicateColor()) {
            jCBDouble.setSelectedIndex(0);
        } else {
            jCBDouble.setSelectedIndex(1);
        }
        jCBPeg.setSelectedIndex((mySettings.getNumberOfPegs() - Settings.ANZ_PEG_MIN));
        jCBRow.setSelectedIndex((mySettings.getNumberOfRows() - Settings.ANZ_GUESS_MIN));
        jCBDesign.setSelectedIndex((mySettings.getDesign() - 1));
    }

    private boolean validateSettings()
    {
        boolean res = false;
        // validate current Settings
        SettingsHandler mySettings = new SettingsHandler();
        //        System.out.println(" Color: " + (Settings.ANZ_COLOR_MIN + jCBColor.getSelectedIndex()));
        //        System.out.println(" Double: " + jCBDouble.getSelectedIndex());
        //        System.out.println(" Peg: " + (Settings.ANZ_PEG_MIN + jCBPeg.getSelectedIndex()));
        //        System.out.println(" Row: " + (Settings.ANZ_GUESS_MIN + jCBRow.getSelectedIndex()));
        //        System.out.println(" Design: " + (jCBDesign.getSelectedIndex() + 1));
        try {
            // try to set new settings...
            mySettings.getSettings().setNumberOfColors((Settings.ANZ_COLOR_MIN + jCBColor.getSelectedIndex()));
            if (jCBDouble.getSelectedIndex() == 0) {
                mySettings.getSettings().setAllowDuplicateColor(true);
            } else {
                mySettings.getSettings().setAllowDuplicateColor(false);
            }
            mySettings.getSettings().setNumberOfPegs((Settings.ANZ_PEG_MIN + jCBPeg.getSelectedIndex()));
            mySettings.getSettings().setNumberOfRows((Settings.ANZ_GUESS_MIN + jCBRow.getSelectedIndex()));
            mySettings.getSettings().setDesign((jCBDesign.getSelectedIndex() + 1));
            // so far so good
            if (mySettings.validSettings()) {
                res = true;
            }
        } catch (Exception e) {
            // dumm gelaufen...
            res = false;
        }
        return res;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jPanel1 = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        jCBColor = new javax.swing.JComboBox();
        jLabel2 = new javax.swing.JLabel();
        jCBDouble = new javax.swing.JComboBox();
        jLabel3 = new javax.swing.JLabel();
        jCBPeg = new javax.swing.JComboBox();
        jLabel4 = new javax.swing.JLabel();
        jCBRow = new javax.swing.JComboBox();
        jPanel2 = new javax.swing.JPanel();
        jLabel5 = new javax.swing.JLabel();
        jCBDesign = new javax.swing.JComboBox();
        jStatus = new javax.swing.JLabel();
        jBSave = new javax.swing.JButton();
        jBCancel = new javax.swing.JButton();

        setMaximumSize(new java.awt.Dimension(400, 150));
        setMinimumSize(new java.awt.Dimension(400, 150));
        setName("Settings"); // NOI18N
        setPreferredSize(new java.awt.Dimension(400, 150));

        jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder("Color Settings"));

        jLabel1.setText("Number of Colors");

        jCBColor.setModel(new javax.swing.DefaultComboBoxModel(jCBColorList));
        jCBColor.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCBActionPerformed(evt);
            }
        });

        jLabel2.setText("Allow duplicate Colors");

        jCBDouble.setModel(new javax.swing.DefaultComboBoxModel(jCBColorDoubleList));
        jCBDouble.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCBActionPerformed(evt);
            }
        });

        jLabel3.setText("Number of Pegs");

        jCBPeg.setModel(new javax.swing.DefaultComboBoxModel(jCBPegList));
        jCBPeg.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCBActionPerformed(evt);
            }
        });

        jLabel4.setText("Number of Attempts");

        jCBRow.setModel(new javax.swing.DefaultComboBoxModel(jCBRowList));
        jCBRow.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jCBActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel1)
                    .addComponent(jLabel2)
                    .addComponent(jLabel3)
                    .addComponent(jLabel4))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jCBPeg, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jCBRow, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jCBDouble, 0, 56, Short.MAX_VALUE)
                    .addComponent(jCBColor, 0, 56, Short.MAX_VALUE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel1)
                    .addComponent(jCBColor, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel2)
                    .addComponent(jCBDouble, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel3)
                    .addComponent(jCBPeg, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel4)
                    .addComponent(jCBRow, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jPanel2.setBorder(javax.swing.BorderFactory.createTitledBorder("Layout"));

        jLabel5.setText("Icon");

        jCBDesign.setModel(new javax.swing.DefaultComboBoxModel(jCBDesignList));

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel5)
                .addGap(18, 18, 18)
                .addComponent(jCBDesign, 0, 103, Short.MAX_VALUE)
                .addContainerGap())
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jCBDesign, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel5, javax.swing.GroupLayout.PREFERRED_SIZE, 14, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jStatus.setText(" ");

        jBSave.setText("Save");
        jBSave.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jBSaveActionPerformed(evt);
            }
        });

        jBCancel.setText("Cancel");
        jBCancel.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jBCancelActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGap(16, 16, 16)
                        .addComponent(jBCancel, javax.swing.GroupLayout.PREFERRED_SIZE, 73, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(18, 18, 18)
                        .addComponent(jBSave, javax.swing.GroupLayout.PREFERRED_SIZE, 73, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(layout.createSequentialGroup()
                        .addGap(18, 18, 18)
                        .addComponent(jStatus, javax.swing.GroupLayout.DEFAULT_SIZE, 166, Short.MAX_VALUE))
                    .addGroup(layout.createSequentialGroup()
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(jPanel2, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(jPanel2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(jStatus, javax.swing.GroupLayout.PREFERRED_SIZE, 19, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jBCancel)
                            .addComponent(jBSave))))
                .addGap(8, 8, 8))
        );
    }// </editor-fold>//GEN-END:initComponents

    private void jBSaveActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_jBSaveActionPerformed
    {//GEN-HEADEREND:event_jBSaveActionPerformed
//        System.out.println("Try to save new Settings...");
        try {
            // try to set new settings...
            SettingsHandler.getInstance().getSettings().setNumberOfColors((Settings.ANZ_COLOR_MIN + jCBColor.getSelectedIndex()));
            if (jCBDouble.getSelectedIndex() == 0) {
                SettingsHandler.getInstance().getSettings().setAllowDuplicateColor(true);
            } else {
                SettingsHandler.getInstance().getSettings().setAllowDuplicateColor(false);
            }
            SettingsHandler.getInstance().getSettings().setNumberOfPegs((Settings.ANZ_PEG_MIN + jCBPeg.getSelectedIndex()));
            SettingsHandler.getInstance().getSettings().setNumberOfRows((Settings.ANZ_GUESS_MIN + jCBRow.getSelectedIndex()));
            SettingsHandler.getInstance().getSettings().setDesign((jCBDesign.getSelectedIndex() + 1));
        } catch (Exception e) {
            // dumm gelaufen...
        }

        if (SettingsHandler.getInstance().validSettings()) {
//            System.out.println(" Color: " + (Settings.ANZ_COLOR_MIN + jCBColor.getSelectedIndex()));
//            System.out.println(" Double: " + jCBDouble.getSelectedIndex());
//            System.out.println(" Peg: " + (Settings.ANZ_PEG_MIN + jCBPeg.getSelectedIndex()));
            
            // Save Settings in file
            SettingsHandler.getInstance().saveSettings();
            myDialog.setVisible(false);
        } else {
            jStatus.setText("Please select playable options...");
        }
    }//GEN-LAST:event_jBSaveActionPerformed

    private void jBCancelActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_jBCancelActionPerformed
    {//GEN-HEADEREND:event_jBCancelActionPerformed
        // TODO add your handling code here:
        myDialog.setVisible(false);
}//GEN-LAST:event_jBCancelActionPerformed

    private void jCBActionPerformed(java.awt.event.ActionEvent evt)//GEN-FIRST:event_jCBActionPerformed
    {//GEN-HEADEREND:event_jCBActionPerformed
        // validate Settings...
        if (validateSettings()) {
            jBSave.setEnabled(true);
            jStatus.setText("");
        } else {
            jBSave.setEnabled(false);
            jStatus.setText("Please select playable options...");
        }
    }//GEN-LAST:event_jCBActionPerformed
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jBCancel;
    private javax.swing.JButton jBSave;
    private javax.swing.JComboBox jCBColor;
    private javax.swing.JComboBox jCBDesign;
    private javax.swing.JComboBox jCBDouble;
    private javax.swing.JComboBox jCBPeg;
    private javax.swing.JComboBox jCBRow;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JLabel jStatus;
    // End of variables declaration//GEN-END:variables
}
