package mastermind.logic;

import mastermind.model.Guess;
import mastermind.model.Settings;

/**
 * Mastermind Settings: Handler für Guess
 */
/* -----------------------------------------------------------------------------
 * Version History:
 * 2012-05-05.v01   FeRo    init version
 * -----------------------------------------------------------------------------
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 * @version 2012-05-05.v01
 */
public class GuessHandler
{

    /**
     * Default Konstruktor
     */
    public GuessHandler()
    {
        //nothing
    }

    /**
     * Ueberprueft die Parameter auf ihre gueltigkeit, Plausibilitaetspruefung.
     * @param pegs Int[] mit den einzelnen Pegs
     * @return falls gültiger Guess -> true
     */
    public static boolean validateGuess(int[] pegs)
    {
        Settings settings = SettingsHandler.getInstance().getSettings();
        // Anzahl Pegs / Länge von Guess
        if (pegs.length != settings.getNumberOfPegs()) {
            return false;
        }
        // Anzahl Farben
        int maxColor = settings.getNumberOfColors();
        int[] tmpColor = new int[(maxColor + 1)];
        for (int i = 0; i < pegs.length; i ++) {
            if ((pegs[i] < 1) || (pegs[i] > maxColor)) {
                // ungültige Farbe
                return false;
            }
            // doppelte Farben erlaubt?
            if ((tmpColor[pegs[i]] != 0) && ( ! settings.getAllowDuplicateColor())) {
                return false;
            } else {
                tmpColor[pegs[i]] = 1; // set Color as used
            }
        }
        return true;
    }

    /**
     * Ueberprueft die Parameter auf ihre gueltigkeit, Plausibilitaetspruefung.
     * @param guess Guess-Objekt mit den einzelnen Pegs
     * @return falls gültiger Guess -> true
     */
    public static boolean validateGuess(Guess guess)
    {
        return (validateGuess(guess.getPegs()));
    }
}
