package mastermind.logic;

import java.util.Random;
import mastermind.model.Guess;
import mastermind.model.Settings;

/**
 * Mastermind Settings: Erzeugt einen Zufalls Guess
 */
/* -----------------------------------------------------------------------------
 * Version History:
 * 2012-05-03.v01   FeRo    init version
 * 2012-05-05.v01   FeRo    SettingsHandler
 * -----------------------------------------------------------------------------
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 * @version 2012-05-05.v01
 */
public class RandomGuess
{

    /**
     * Erzeugt einen zufälligen Guess
     * @return zufalls Guess
     */
    public static Guess genRandomGuess() {
        // get Settings
        Settings settings = SettingsHandler.getInstance().getSettings();

        if ((( ! settings.getAllowDuplicateColor()) && (settings.getNumberOfColors() < settings.getNumberOfPegs()))
            || (settings.getNumberOfColors() < 0)
            || (settings.getNumberOfPegs() < 0)
            || (settings.getNumberOfRows() < 0)) {
            // prevent infinite loop
            throw new IllegalArgumentException("NOT allowDuplicateColor & (NumberOfColors < NumberOfPegs)");
        }

        Random rnd = new Random();
        int[] usedAllowedColor = new int[settings.getNumberOfColors()]; // 0 = not yes used, 1 = used
        int[] rndPeg = new int[settings.getNumberOfPegs()];
        for (int i = 0; i < settings.getNumberOfPegs(); i ++) {
            int tmpInt = -1;
            do {
                tmpInt = rnd.nextInt(settings.getNumberOfColors()) + 1;
                if ( ! settings.getAllowDuplicateColor()) {
                    if (usedAllowedColor[(tmpInt - 1)] == 1) {
                        // this color is allready used
                        tmpInt = -1;
                    } else {
                        // set this color as used
                        usedAllowedColor[(tmpInt - 1)] = 1;
                    }
                }
            } while (tmpInt == -1);
            rndPeg[i] = tmpInt;
        }
        return (new Guess(rndPeg));
    }
}
